Struct CompletionToken

pub struct CompletionToken(/* private fields */);
Token for listening for responses to requests

These tokens are always guaranteed, to have at most one equal counterpart, and they are deliberately not Cloneable or Copyable to help enforce that constraint.

Internally, the token contains a u64 sourced from an incrementing atomic, no guarantees are made about iteration order, and the tokens have no meaning across executions.

Implementations

Source

impl CompletionToken

pub fn new() -> (CompletionToken, CompletionToken)

Creates a pair of equal CompletionTokens

It is guaranteed that no previous or future pair of CompletionTokens, at least within a single execution of the program, will be equal to these tokens

pub fn count(&self) -> usize

Returns the number of copies of this CompletionToken currently alive

This is used for doing “Garbage Collection” of token’s whose partners have been dropped.