Module util

Utility types and wrappers for working with events

Structs

Adaptor
Adaptor that allows connecting an EventConsumer to an EventProducer of a different type using a conversion closure
AsyncActor
A basic actor that listens to its Inbox asynchronously on a background task
AsyncWrappedReceiver
Wrapper around a flume channel receiver that adapts it into an EventProducer
SyncActor
A basic actor that listens to its Inbox asynchronously on a background task
TokenManager
Utility type for managing CompletionTokens used for callbacks when implementing an Actor
WrappedEvent
Wrapper around compatible types that implements Event by keeping just enough manually controlled state variables to implement the Event api, with no business logic aside from the provided setters.

Enums

AsyncActorError
Error connecting to AsyncActor
EitherError
An error that can be one of two types
SyncActorError
Error connecting to SyncActor
WrappedReceiverError
Error type for WrappedReceiver