Utility types and wrappers for working with events
Structs
- Adaptor
- Adaptor that allows connecting an
EventConsumerto anEventProducerof a different type using a conversion closure - Async
Actor - A basic actor that listens to its
Inboxasynchronously on a background task - Async
Wrapped Receiver - Wrapper around a flume channel receiver that adapts it into an
EventProducer - Sync
Actor - A basic actor that listens to its
Inboxasynchronously on a background task - Token
Manager - Utility type for managing
CompletionTokens used for callbacks when implementing anActor - Wrapped
Event - Wrapper around compatible types that implements
Eventby keeping just enough manually controlled state variables to implement theEventapi, with no business logic aside from the provided setters.
Enums
- Async
Actor Error - Error connecting to
AsyncActor - Either
Error - An error that can be one of two types
- Sync
Actor Error - Error connecting to
SyncActor - Wrapped
Receiver Error - Error type for
WrappedReceiver